@@ -628,6 +628,37 @@ def genpdf(maadstoken,maads_rest_url,pkey,urltomaadsserver,savetofolder,username
     except Exception as e:  
       return "ERROR: Retrieving PDF: %s" % e 
 
+def optimize (maadstoken,maads_rest_url,algo1,ismin=1,objeq='1,1,1',a1cons=1,forceupdate=0,algo2='',algo3='',a2cons=1,a3cons=1,iters=100,step=3,perc='min_0_max_0'):
+
+    if len(algo1)<=0:
+        return "ERROR: Algo 1 must be specified"
+
+    
+    files = {'mode':'optimize',        
+        'algo1': algo1,
+        'algo2': algo2,
+        'algo3': algo3,
+        'forceupdate': forceupdate,
+             
+        'maadstoken':maadstoken,     
+        'a1cons':a1cons,
+        'a2cons':a2cons,
+        'a3cons':a3cons,
+        'ismin':ismin,
+        'rowlen':iters,
+        'step':step,
+        'perc':perc,     
+        'objeq':objeq     
+      }
+    try:
+      r = requests.post(maads_rest_url, files)
+      msg = r.text
+    except Exception as e:
+      return "ERROR Optimizing.  Check your parameters."  
+   
+    return msg
+
+    
 def algoinfo(maadstoken,maads_rest_url,pkey,isrest=0,username='',passw='',company='',email=''):
     files = {'mode':'algoinfo',        
         'username': username,
